@@ -1,5 +1,6 @@
+import itertools
 from copy import copy
-from typing import Any, Union, Optional
+from typing import Any, Optional, Union
 
 from pypika.enums import Dialects
 from pypika.queries import (
@@ -7,51 +8,79 @@ from pypika.queries import (
     Query,
     QueryBuilder,
     Table,
+    DropQueryBuilder,
 )
-from pypika.terms import (
-    ArithmeticExpression,
-    EmptyCriterion,
-    Field,
-    Function,
-    Star,
-    Term,
-    ValueWrapper,
-    Criterion,
-)
+from pypika.terms import ArithmeticExpression, Criterion, EmptyCriterion, Field, Function, Star, Term, ValueWrapper
 from pypika.utils import (
     QueryException,
     builder,
 )
 
 
-class SnowFlakeQueryBuilder(QueryBuilder):
-    QUOTE_CHAR = None
-    ALIAS_QUOTE_CHAR = '"'
-    QUERY_ALIAS_QUOTE_CHAR = ''
-
-    def __init__(self, **kwargs: Any) -> None:
-        super().__init__(
-              dialect=Dialects.SNOWFLAKE, **kwargs
-        )
-
-
 class SnowflakeQuery(Query):
     """
     Defines a query class for use with Snowflake.
     """
 
     @classmethod
-    def _builder(cls, **kwargs: Any) -> SnowFlakeQueryBuilder:
-        return SnowFlakeQueryBuilder(**kwargs)
+    def _builder(cls, **kwargs: Any) -> "SnowflakeQueryBuilder":
+        return SnowflakeQueryBuilder(**kwargs)
+
+    @classmethod
+    def create_table(cls, table: Union[str, Table]) -> "SnowflakeCreateQueryBuilder":
+        return SnowflakeCreateQueryBuilder().create_table(table)
+
+    @classmethod
+    def drop_table(cls, table: Union[str, Table]) -> "SnowflakeDropQueryBuilder":
+        return SnowflakeDropQueryBuilder().drop_table(table)
+
+
+class SnowflakeQueryBuilder(QueryBuilder):
+    QUOTE_CHAR = None
+    ALIAS_QUOTE_CHAR = '"'
+    QUERY_ALIAS_QUOTE_CHAR = ''
+    QUERY_CLS = SnowflakeQuery
+
+    def __init__(self, **kwargs: Any) -> None:
+        super().__init__(dialect=Dialects.SNOWFLAKE, **kwargs)
+
+
+class SnowflakeCreateQueryBuilder(CreateQueryBuilder):
+    QUOTE_CHAR = None
+    QUERY_CLS = SnowflakeQuery
+
+    def __init__(self) -> None:
+        super().__init__(dialect=Dialects.SNOWFLAKE)
+
+
+class SnowflakeDropQueryBuilder(DropQueryBuilder):
+    QUOTE_CHAR = None
+    QUERY_CLS = SnowflakeQuery
+
+    def __init__(self) -> None:
+        super().__init__(dialect=Dialects.SNOWFLAKE)
+
+
+class MySQLQuery(Query):
+    """
+    Defines a query class for use with MySQL.
+    """
+
+    @classmethod
+    def _builder(cls, **kwargs: Any) -> "MySQLQueryBuilder":
+        return MySQLQueryBuilder(**kwargs)
+
+    @classmethod
+    def load(cls, fp: str) -> "MySQLLoadQueryBuilder":
+        return MySQLLoadQueryBuilder().load(fp)
 
 
 class MySQLQueryBuilder(QueryBuilder):
     QUOTE_CHAR = "`"
+    QUERY_CLS = MySQLQuery
 
     def __init__(self, **kwargs: Any) -> None:
-        super().__init__(
-              dialect=Dialects.MYSQL, wrap_set_operation_queries=False, **kwargs
-        )
+        super().__init__(dialect=Dialects.MYSQL, wrap_set_operation_queries=False, **kwargs)
         self._duplicate_updates = []
         self._ignore_duplicates = False
         self._modifiers = []
@@ -89,12 +118,10 @@ class MySQLQueryBuilder(QueryBuilder):
 
     def _on_duplicate_key_update_sql(self, **kwargs: Any) -> str:
         return " ON DUPLICATE KEY UPDATE {updates}".format(
-              updates=",".join(
-                    "{field}={value}".format(
-                          field=field.get_sql(**kwargs), value=value.get_sql(**kwargs)
-                    )
-                    for field, value in self._duplicate_updates
-              )
+            updates=",".join(
+                "{field}={value}".format(field=field.get_sql(**kwargs), value=value.get_sql(**kwargs))
+                for field, value in self._duplicate_updates
+            )
         )
 
     def _on_duplicate_key_ignore_sql(self) -> str:
@@ -116,26 +143,25 @@ class MySQLQueryBuilder(QueryBuilder):
         with the addition of the a modifier if present.
         """
         return "SELECT {distinct}{modifier}{select}".format(
-              distinct="DISTINCT " if self._distinct else "",
-              modifier="{} ".format(" ".join(self._modifiers)) if self._modifiers else "",
-              select=",".join(
-                    term.get_sql(with_alias=True, subquery=True, **kwargs)
-                    for term in self._selects
-              ),
+            distinct="DISTINCT " if self._distinct else "",
+            modifier="{} ".format(" ".join(self._modifiers)) if self._modifiers else "",
+            select=",".join(term.get_sql(with_alias=True, subquery=True, **kwargs) for term in self._selects),
         )
 
 
 class MySQLLoadQueryBuilder:
+    QUERY_CLS = MySQLQuery
+
     def __init__(self) -> None:
         self._load_file = None
         self._into_table = None
 
     @builder
-    def load(self, fp: str) -> "MySQLQueryBuilder":
+    def load(self, fp: str) -> "MySQLLoadQueryBuilder":
         self._load_file = fp
 
     @builder
-    def into(self, table: Union[str, Table]) -> "MySQLQueryBuilder":
+    def into(self, table: Union[str, Table]) -> "MySQLLoadQueryBuilder":
         self._into_table = table if isinstance(table, Table) else Table(table)
 
     def get_sql(self, *args: Any, **kwargs: Any) -> str:
@@ -160,21 +186,27 @@ class MySQLLoadQueryBuilder:
         return self.get_sql()
 
 
-class MySQLQuery(Query):
+class VerticaQuery(Query):
     """
-    Defines a query class for use with MySQL.
+    Defines a query class for use with Vertica.
     """
 
     @classmethod
-    def _builder(cls, **kwargs: Any) -> "MySQLQueryBuilder":
-        return MySQLQueryBuilder(**kwargs)
+    def _builder(cls, **kwargs) -> "VerticaQueryBuilder":
+        return VerticaQueryBuilder(**kwargs)
 
     @classmethod
-    def load(cls, fp: str) -> "MySQLQueryBuilder":
-        return MySQLLoadQueryBuilder().load(fp)
+    def from_file(cls, fp: str) -> "VerticaCopyQueryBuilder":
+        return VerticaCopyQueryBuilder().from_file(fp)
+
+    @classmethod
+    def create_table(cls, table: Union[str, Table]) -> "VerticaCreateQueryBuilder":
+        return VerticaCreateQueryBuilder().create_table(table)
 
 
 class VerticaQueryBuilder(QueryBuilder):
+    QUERY_CLS = VerticaQuery
+
     def __init__(self, **kwargs: Any) -> None:
         super().__init__(dialect=Dialects.VERTICA, **kwargs)
         self._hint = None
@@ -187,14 +219,14 @@ class VerticaQueryBuilder(QueryBuilder):
         sql = super().get_sql(*args, **kwargs)
 
         if self._hint is not None:
-            sql = "".join(
-                  [sql[:7], "/*+label({hint})*/".format(hint=self._hint), sql[6:]]
-            )
+            sql = "".join([sql[:7], "/*+label({hint})*/".format(hint=self._hint), sql[6:]])
 
         return sql
 
 
 class VerticaCreateQueryBuilder(CreateQueryBuilder):
+    QUERY_CLS = VerticaQuery
+
     def __init__(self) -> None:
         super().__init__(dialect=Dialects.VERTICA)
         self._local = False
@@ -216,21 +248,20 @@ class VerticaCreateQueryBuilder(CreateQueryBuilder):
 
     def _create_table_sql(self, **kwargs: Any) -> str:
         return "CREATE {local}{temporary}TABLE {table}".format(
-              local="LOCAL " if self._local else "",
-              temporary="TEMPORARY " if self._temporary else "",
-              table=self._create_table.get_sql(**kwargs),
+            local="LOCAL " if self._local else "",
+            temporary="TEMPORARY " if self._temporary else "",
+            table=self._create_table.get_sql(**kwargs),
         )
 
-    def _columns_sql(self, **kwargs: Any) -> str:
-        return " ({columns}){preserve_rows}".format(
-              columns=",".join(column.get_sql(**kwargs) for column in self._columns),
-              preserve_rows=self._preserve_rows_sql(),
-        )
+    def _table_options_sql(self, **kwargs) -> str:
+        table_options = super()._table_options_sql(**kwargs)
+        table_options += self._preserve_rows_sql()
+        return table_options
 
     def _as_select_sql(self, **kwargs: Any) -> str:
         return "{preserve_rows} AS ({query})".format(
-              preserve_rows=self._preserve_rows_sql(),
-              query=self._as_select.get_sql(**kwargs),
+            preserve_rows=self._preserve_rows_sql(),
+            query=self._as_select.get_sql(**kwargs),
         )
 
     def _preserve_rows_sql(self) -> str:
@@ -238,6 +269,8 @@ class VerticaCreateQueryBuilder(CreateQueryBuilder):
 
 
 class VerticaCopyQueryBuilder:
+    QUERY_CLS = VerticaQuery
+
     def __init__(self) -> None:
         self._copy_table = None
         self._from_file = None
@@ -272,48 +305,45 @@ class VerticaCopyQueryBuilder:
         return self.get_sql()
 
 
-class VerticaQuery(Query):
-    """
-    Defines a query class for use with Vertica.
-    """
-
-    @classmethod
-    def _builder(cls, **kwargs) -> VerticaQueryBuilder:
-        return VerticaQueryBuilder(**kwargs)
-
-    @classmethod
-    def from_file(cls, fp: str) -> VerticaCopyQueryBuilder:
-        return VerticaCopyQueryBuilder().from_file(fp)
-
-    @classmethod
-    def create_table(cls, table: Union[str, Table]) -> VerticaCreateQueryBuilder:
-        return VerticaCreateQueryBuilder().create_table(table)
-
-
-class OracleQueryBuilder(QueryBuilder):
-    def __init__(self, **kwargs: Any) -> None:
-        super().__init__(dialect=Dialects.ORACLE, **kwargs)
-
-    def get_sql(self, *args: Any, **kwargs: Any) -> str:
-        return super().get_sql(
-              *args, groupby_alias=False, **kwargs
-        )
-
-
 class OracleQuery(Query):
     """
     Defines a query class for use with Oracle.
     """
 
     @classmethod
-    def _builder(cls, **kwargs: Any) -> OracleQueryBuilder:
+    def _builder(cls, **kwargs: Any) -> "OracleQueryBuilder":
         return OracleQueryBuilder(**kwargs)
 
 
-class PostgreQueryBuilder(QueryBuilder):
-    ALIAS_QUOTE_CHAR = '"'
+class OracleQueryBuilder(QueryBuilder):
+    QUOTE_CHAR = None
+    QUERY_CLS = OracleQuery
 
-    def __init__(self, **kwargs: str) -> None:
+    def __init__(self, **kwargs: Any) -> None:
+        super().__init__(dialect=Dialects.ORACLE, **kwargs)
+
+    def get_sql(self, *args: Any, **kwargs: Any) -> str:
+        # Oracle does not support group by a field alias
+        # Note: set directly in kwargs as they are re-used down the tree in the case of subqueries!
+        kwargs['groupby_alias'] = False
+        return super().get_sql(*args, **kwargs)
+
+
+class PostgreSQLQuery(Query):
+    """
+    Defines a query class for use with PostgreSQL.
+    """
+
+    @classmethod
+    def _builder(cls, **kwargs) -> "PostgreSQLQueryBuilder":
+        return PostgreSQLQueryBuilder(**kwargs)
+
+
+class PostgreSQLQueryBuilder(QueryBuilder):
+    ALIAS_QUOTE_CHAR = '"'
+    QUERY_CLS = PostgreSQLQuery
+
+    def __init__(self, **kwargs: Any) -> None:
         super().__init__(dialect=Dialects.POSTGRESQL, **kwargs)
         self._returns = []
         self._return_star = False
@@ -327,14 +357,14 @@ class PostgreQueryBuilder(QueryBuilder):
 
         self._distinct_on = []
 
-    def __copy__(self) -> "PostgreQueryBuilder":
+    def __copy__(self) -> "PostgreSQLQueryBuilder":
         newone = super().__copy__()
         newone._returns = copy(self._returns)
         newone._on_conflict_do_updates = copy(self._on_conflict_do_updates)
         return newone
 
     @builder
-    def distinct_on(self, *fields: Union[str, Term]) -> "PostgreQueryBuilder":
+    def distinct_on(self, *fields: Union[str, Term]) -> "PostgreSQLQueryBuilder":
         for field in fields:
             if isinstance(field, str):
                 self._distinct_on.append(Field(field))
@@ -342,7 +372,7 @@ class PostgreQueryBuilder(QueryBuilder):
                 self._distinct_on.append(field)
 
     @builder
-    def on_conflict(self, *target_fields: Union[str, Term]) -> "PostgreQueryBuilder":
+    def on_conflict(self, *target_fields: Union[str, Term]) -> "PostgreSQLQueryBuilder":
         if not self._insert_table:
             raise QueryException("On conflict only applies to insert query")
 
@@ -355,13 +385,15 @@ class PostgreQueryBuilder(QueryBuilder):
                 self._on_conflict_fields.append(target_field)
 
     @builder
-    def do_nothing(self) -> "PostgreQueryBuilder":
+    def do_nothing(self) -> "PostgreSQLQueryBuilder":
         if len(self._on_conflict_do_updates) > 0:
             raise QueryException("Can not have two conflict handlers")
         self._on_conflict_do_nothing = True
 
     @builder
-    def do_update(self, update_field: Union[str, Field], update_value: Any) -> "PostgreQueryBuilder":
+    def do_update(
+        self, update_field: Union[str, Field], update_value: Optional[Any] = None
+    ) -> "PostgreSQLQueryBuilder":
         if self._on_conflict_do_nothing:
             raise QueryException("Can not have two conflict handlers")
 
@@ -372,10 +404,13 @@ class PostgreQueryBuilder(QueryBuilder):
         else:
             raise QueryException("Unsupported update_field")
 
-        self._on_conflict_do_updates.append((field, ValueWrapper(update_value)))
+        if update_value is not None:
+            self._on_conflict_do_updates.append((field, ValueWrapper(update_value)))
+        else:
+            self._on_conflict_do_updates.append((field, None))
 
     @builder
-    def where(self, criterion: Criterion) -> "PostgreQueryBuilder":
+    def where(self, criterion: Criterion) -> "PostgreSQLQueryBuilder":
         if not self._on_conflict:
             return super().where(criterion)
 
@@ -401,9 +436,7 @@ class PostgreQueryBuilder(QueryBuilder):
     def _distinct_sql(self, **kwargs: Any) -> str:
         if self._distinct_on:
             return "DISTINCT ON({distinct_on}) ".format(
-                  distinct_on=",".join(
-                        term.get_sql(with_alias=True, **kwargs) for term in self._distinct_on
-                  )
+                distinct_on=",".join(term.get_sql(with_alias=True, **kwargs) for term in self._distinct_on)
             )
         return super()._distinct_sql(**kwargs)
 
@@ -422,14 +455,11 @@ class PostgreQueryBuilder(QueryBuilder):
 
         conflict_query = " ON CONFLICT"
         if self._on_conflict_fields:
-            fields = [f.get_sql(with_alias=True, **kwargs)
-                      for f in self._on_conflict_fields]
+            fields = [f.get_sql(with_alias=True, **kwargs) for f in self._on_conflict_fields]
             conflict_query += " (" + ', '.join(fields) + ")"
 
         if self._on_conflict_wheres:
-            conflict_query += " WHERE {where}".format(
-                  where=self._on_conflict_wheres.get_sql(subquery=True, **kwargs)
-            )
+            conflict_query += " WHERE {where}".format(where=self._on_conflict_wheres.get_sql(subquery=True, **kwargs))
 
         return conflict_query
 
@@ -437,26 +467,34 @@ class PostgreQueryBuilder(QueryBuilder):
         if self._on_conflict_do_nothing:
             return " DO NOTHING"
         elif len(self._on_conflict_do_updates) > 0:
-            action_sql = " DO UPDATE SET {updates}".format(
-                  updates=",".join(
+            updates = []
+            for field, value in self._on_conflict_do_updates:
+                if value:
+                    updates.append(
                         "{field}={value}".format(
-                              field=field.get_sql(**kwargs),
-                              value=value.get_sql(with_namespace=True, **kwargs),
+                            field=field.get_sql(**kwargs),
+                            value=value.get_sql(with_namespace=True, **kwargs),
                         )
-                        for field, value in self._on_conflict_do_updates
-                  )
-            )
+                    )
+                else:
+                    updates.append(
+                        "{field}=EXCLUDED.{value}".format(
+                            field=field.get_sql(**kwargs),
+                            value=field.get_sql(**kwargs),
+                        )
+                    )
+            action_sql = " DO UPDATE SET {updates}".format(updates=",".join(updates))
 
             if self._on_conflict_do_update_wheres:
                 action_sql += " WHERE {where}".format(
-                      where=self._on_conflict_do_update_wheres.get_sql(subquery=True, with_namespace=True, **kwargs)
+                    where=self._on_conflict_do_update_wheres.get_sql(subquery=True, with_namespace=True, **kwargs)
                 )
             return action_sql
 
         return ''
 
     @builder
-    def returning(self, *terms: Any) -> "PostgreQueryBuilder":
+    def returning(self, *terms: Any) -> "PostgreSQLQueryBuilder":
         for term in terms:
             if isinstance(term, Field):
                 self._return_field(term)
@@ -473,16 +511,16 @@ class PostgreQueryBuilder(QueryBuilder):
         for field in term.fields_():
             if not any([self._insert_table, self._update_table, self._delete_from]):
                 raise QueryException("Returning can't be used in this query")
-            if (
-                  field.table not in {self._insert_table, self._update_table}
-                  and term not in self._from
-            ):
+
+            table_is_insert_or_update_table = field.table in {self._insert_table, self._update_table}
+            join_tables = set(itertools.chain.from_iterable([j.criterion.tables_ for j in self._joins]))
+            join_and_base_tables = set(self._from) | join_tables
+            table_not_base_or_join = bool(term.tables_ - join_and_base_tables)
+            if not table_is_insert_or_update_table and table_not_base_or_join:
                 raise QueryException("You can't return from other tables")
 
     def _set_returns_for_star(self) -> None:
-        self._returns = [
-            returning for returning in self._returns if not hasattr(returning, "table")
-        ]
+        self._returns = [returning for returning in self._returns if not hasattr(returning, "table")]
         self._return_star = True
 
     def _return_field(self, term: Union[str, Field]) -> None:
@@ -518,17 +556,13 @@ class PostgreQueryBuilder(QueryBuilder):
 
     def _returning_sql(self, **kwargs: Any) -> str:
         return " RETURNING {returning}".format(
-              returning=",".join(
-                    term.get_sql(with_alias=True, **kwargs) for term in self._returns
-              ),
+            returning=",".join(term.get_sql(with_alias=True, **kwargs) for term in self._returns),
         )
 
     def get_sql(self, with_alias: bool = False, subquery: bool = False, **kwargs: Any) -> str:
         self._set_kwargs_defaults(kwargs)
 
-        querystring = super(PostgreQueryBuilder, self).get_sql(
-              with_alias, subquery, **kwargs
-        )
+        querystring = super(PostgreSQLQueryBuilder, self).get_sql(with_alias, subquery, **kwargs)
 
         querystring += self._on_conflict_sql(**kwargs)
         querystring += self._on_conflict_action_sql(**kwargs)
@@ -539,27 +573,33 @@ class PostgreQueryBuilder(QueryBuilder):
         return querystring
 
 
-class PostgreSQLQuery(Query):
-    """
-    Defines a query class for use with PostgreSQL.
-    """
-
-    @classmethod
-    def _builder(cls, **kwargs) -> PostgreQueryBuilder:
-        return PostgreQueryBuilder(**kwargs)
-
-
 class RedshiftQuery(Query):
     """
     Defines a query class for use with Amazon Redshift.
     """
 
     @classmethod
-    def _builder(cls, **kwargs: Any) -> "QueryBuilder":
-        return QueryBuilder(dialect=Dialects.REDSHIFT, **kwargs)
+    def _builder(cls, **kwargs: Any) -> "RedShiftQueryBuilder":
+        return RedShiftQueryBuilder(dialect=Dialects.REDSHIFT, **kwargs)
+
+
+class RedShiftQueryBuilder(QueryBuilder):
+    QUERY_CLS = RedshiftQuery
+
+
+class MSSQLQuery(Query):
+    """
+    Defines a query class for use with Microsoft SQL Server.
+    """
+
+    @classmethod
+    def _builder(cls, **kwargs: Any) -> "MSSQLQueryBuilder":
+        return MSSQLQueryBuilder(**kwargs)
 
 
 class MSSQLQueryBuilder(QueryBuilder):
+    QUERY_CLS = MSSQLQuery
+
     def __init__(self, **kwargs: Any) -> None:
         super().__init__(dialect=Dialects.MSSQL, **kwargs)
         self._top = None
@@ -601,9 +641,10 @@ class MSSQLQueryBuilder(QueryBuilder):
         return querystring
 
     def get_sql(self, *args: Any, **kwargs: Any) -> str:
-        return super().get_sql(
-            *args, groupby_alias=False, **kwargs
-        )
+        # MSSQL does not support group by a field alias.
+        # Note: set directly in kwargs as they are re-used down the tree in the case of subqueries!
+        kwargs['groupby_alias'] = False
+        return super().get_sql(*args, **kwargs)
 
     def _top_sql(self) -> str:
         if self._top:
@@ -613,32 +654,49 @@ class MSSQLQueryBuilder(QueryBuilder):
 
     def _select_sql(self, **kwargs: Any) -> str:
         return "SELECT {distinct}{top}{select}".format(
-              top=self._top_sql(),
-              distinct="DISTINCT " if self._distinct else "",
-              select=",".join(
-                    term.get_sql(with_alias=True, subquery=True, **kwargs)
-                    for term in self._selects
-              ),
+            top=self._top_sql(),
+            distinct="DISTINCT " if self._distinct else "",
+            select=",".join(term.get_sql(with_alias=True, subquery=True, **kwargs) for term in self._selects),
         )
 
 
-class MSSQLQuery(Query):
-    """
-    Defines a query class for use with Microsoft SQL Server.
-    """
-
-    @classmethod
-    def _builder(cls, **kwargs: Any) -> MSSQLQueryBuilder:
-        return MSSQLQueryBuilder(**kwargs)
-
-
 class ClickHouseQuery(Query):
     """
     Defines a query class for use with Yandex ClickHouse.
     """
+
     @classmethod
-    def _builder(cls, **kwargs: Any) -> QueryBuilder:
-        return QueryBuilder(dialect=Dialects.CLICKHOUSE, wrap_set_operation_queries=False, as_keyword=True, **kwargs)
+    def _builder(cls, **kwargs: Any) -> "ClickHouseQueryBuilder":
+        return ClickHouseQueryBuilder(
+            dialect=Dialects.CLICKHOUSE, wrap_set_operation_queries=False, as_keyword=True, **kwargs
+        )
+
+
+class ClickHouseQueryBuilder(QueryBuilder):
+    QUERY_CLS = ClickHouseQuery
+
+    @staticmethod
+    def _delete_sql(**kwargs: Any) -> str:
+        return 'ALTER TABLE'
+
+    def _update_sql(self, **kwargs: Any) -> str:
+        return "ALTER TABLE {table}".format(table=self._update_table.get_sql(**kwargs))
+
+    def _from_sql(self, with_namespace: bool = False, **kwargs: Any) -> str:
+        selectable = ",".join(clause.get_sql(subquery=True, with_alias=True, **kwargs) for clause in self._from)
+        if self._delete_from:
+            return " {selectable} DELETE".format(selectable=selectable)
+        return " FROM {selectable}".format(selectable=selectable)
+
+    def _set_sql(self, **kwargs: Any) -> str:
+        return " UPDATE {set}".format(
+            set=",".join(
+                "{field}={value}".format(
+                    field=field.get_sql(**dict(kwargs, with_namespace=False)), value=value.get_sql(**kwargs)
+                )
+                for field, value in self._updates
+            )
+        )
 
 
 class SQLLiteValueWrapper(ValueWrapper):
@@ -654,7 +712,9 @@ class SQLLiteQuery(Query):
     """
 
     @classmethod
-    def _builder(cls, **kwargs: Any) -> QueryBuilder:
-        return QueryBuilder(
-              dialect=Dialects.SQLLITE, wrapper_cls=SQLLiteValueWrapper, **kwargs
-        )
+    def _builder(cls, **kwargs: Any) -> "SQLLiteQueryBuilder":
+        return SQLLiteQueryBuilder(dialect=Dialects.SQLLITE, wrapper_cls=SQLLiteValueWrapper, **kwargs)
+
+
+class SQLLiteQueryBuilder(QueryBuilder):
+    QUERY_CLS = SQLLiteQuery
